==> jc-1.4.0.tar.gz: java/awt/event/ComponentEvent.h <==
// public class java.awt.event.ComponentEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_ComponentEvent_H_
#define _JC_java_awt_event_ComponentEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ComponentEvent$sub_refs	_jc_java_awt_event_ComponentEvent$sub_refs;
typedef struct _jc_java_awt_event_ComponentEvent$sub_nonrefs	_jc_java_awt_event_ComponentEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ComponentEvent$refs	_jc_java_awt_event_ComponentEvent$refs;
typedef struct _jc_java_awt_event_ComponentEvent$nonrefs	_jc_java_awt_event_ComponentEvent$nonrefs;
typedef struct _jc_java_awt_event_ComponentEvent$object	_jc_java_awt_event_ComponentEvent$object;

typedef struct _jc_java_awt_event_ComponentEvent$fields_struct	_jc_java_awt_event_ComponentEvent$fields_struct;
typedef const struct _jc_java_awt_event_ComponentEvent$vmethods	_jc_java_awt_event_ComponentEvent$vmethods;
typedef const struct _jc_java_awt_event_ComponentEvent$vtable	_jc_java_awt_event_ComponentEvent$vtable;
typedef const struct _jc_java_awt_event_ComponentEvent$vtype	_jc_java_awt_event_ComponentEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ComponentEvent$fields_struct {
	jlong	serialVersionUID;
	jint	COMPONENT__5fFIRST;
	jint	COMPONENT__5fHIDDEN;
	jint	COMPONENT__5fLAST;
	jint	COMPONENT__5fMOVED;
	jint	COMPONENT__5fRESIZED;
	jint	COMPONENT__5fSHOWN;
};
extern _jc_java_awt_event_ComponentEvent$fields_struct _jc_java_awt_event_ComponentEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ComponentEvent$method$_init$97af01f308697cf5(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *, struct _jc_java_awt_Component$object *, jint);

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_ComponentEvent$method$getComponent$c7b7faa3c34ca595(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ComponentEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ComponentEvent$method_info$getComponent$c7b7faa3c34ca595;
extern _jc_method _jc_java_awt_event_ComponentEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ComponentEvent$vmethods {
	struct _jc_java_awt_Component$object	*(*getComponent$c7b7faa3c34ca595)(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *);
};

// Vtable
struct _jc_java_awt_event_ComponentEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
};

// Vtype
struct _jc_java_awt_event_ComponentEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ComponentEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ComponentEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_ComponentEvent$refs {
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ComponentEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ComponentEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
};

// Object instance structure
struct _jc_java_awt_event_ComponentEvent$object {
	_jc_java_awt_event_ComponentEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ComponentEvent$vtype	*vtype;
	_jc_java_awt_event_ComponentEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ComponentEvent$vtype _jc_java_awt_event_ComponentEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ComponentEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ComponentEvent$class_object;

#endif	/* _JC_java_awt_event_ComponentEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/ComponentEvent.h <==
// public class java.awt.event.ComponentEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_ComponentEvent_H_
#define _JC_java_awt_event_ComponentEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ComponentEvent$sub_refs	_jc_java_awt_event_ComponentEvent$sub_refs;
typedef struct _jc_java_awt_event_ComponentEvent$sub_nonrefs	_jc_java_awt_event_ComponentEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ComponentEvent$refs	_jc_java_awt_event_ComponentEvent$refs;
typedef struct _jc_java_awt_event_ComponentEvent$nonrefs	_jc_java_awt_event_ComponentEvent$nonrefs;
typedef struct _jc_java_awt_event_ComponentEvent$object	_jc_java_awt_event_ComponentEvent$object;

typedef struct _jc_java_awt_event_ComponentEvent$fields_struct	_jc_java_awt_event_ComponentEvent$fields_struct;
typedef const struct _jc_java_awt_event_ComponentEvent$vmethods	_jc_java_awt_event_ComponentEvent$vmethods;
typedef const struct _jc_java_awt_event_ComponentEvent$vtable	_jc_java_awt_event_ComponentEvent$vtable;
typedef const struct _jc_java_awt_event_ComponentEvent$vtype	_jc_java_awt_event_ComponentEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ComponentEvent$fields_struct {
	jlong	serialVersionUID;
	jint	COMPONENT__5fFIRST;
	jint	COMPONENT__5fHIDDEN;
	jint	COMPONENT__5fLAST;
	jint	COMPONENT__5fMOVED;
	jint	COMPONENT__5fRESIZED;
	jint	COMPONENT__5fSHOWN;
};
extern _jc_java_awt_event_ComponentEvent$fields_struct _jc_java_awt_event_ComponentEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ComponentEvent$method$_init$97af01f308697cf5(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *, struct _jc_java_awt_Component$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_ComponentEvent$method$getComponent$c7b7faa3c34ca595(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ComponentEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ComponentEvent$method_info$getComponent$c7b7faa3c34ca595;
extern _jc_method _jc_java_awt_event_ComponentEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ComponentEvent$vmethods {
	struct _jc_java_awt_Component$object	*(*getComponent$c7b7faa3c34ca595)(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_ComponentEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
};

// Vtype
struct _jc_java_awt_event_ComponentEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ComponentEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ComponentEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_ComponentEvent$refs {
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ComponentEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ComponentEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
};

// Object instance structure
struct _jc_java_awt_event_ComponentEvent$object {
	_jc_java_awt_event_ComponentEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ComponentEvent$vtype	*vtype;
	_jc_java_awt_event_ComponentEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ComponentEvent$vtype _jc_java_awt_event_ComponentEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ComponentEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ComponentEvent$class_object;

#endif	/* _JC_java_awt_event_ComponentEvent_H_ */
